@@ -718,11 +718,11 @@ int CCanvas::getCurrentPos(qreal& x, qreal& y, qreal &ele)
 void CCanvas::orientationChanged(const QString &newOrientation)
 {
 	if (newOrientation == QLatin1String(MCE_ORIENTATION_PORTRAIT)) {
-		setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
-		setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, false);
+		setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+		setAttribute(Qt::WA_Maemo5LandscapeOrientation, false);
 	}
 	else {
-		setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, true);
-		setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, false);
+		setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
+		setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
 	}
 }
