@@ -126,11 +126,13 @@ void CNokia::slotGpsRead(LocationGPSDevice *device)
             satellites[idxSat].snr = dataSat->signal_strength;
        }
     }
-
-    if (!(device->fix->fields & LOCATION_GPS_DEVICE_TIME_SET)) {
+    /*
+    if (!(device->fix->fields & LOCATION_GPS_DEVICE_TIME_SET) || 
+	!(device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET)
+    ) {
 	return;
     }
-
+    */
     if (device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET) {
 	    	lat = device->fix->latitude * DEG_TO_RAD;
 	    	lon = device->fix->longitude * DEG_TO_RAD;
@@ -152,14 +154,14 @@ void CNokia::slotGpsRead(LocationGPSDevice *device)
 	    
     haveSeenData = true;
     emit sigNewData(*this);
-
-    portChanged();
+    qApp->processEvents();
 }
 
 
 void CNokia::slotWatchdog()
 {
     if((device != NULL) && haveSeenData) {
+    	sysError = "";
         haveSeenData = false;
         return;
     }
@@ -173,15 +175,16 @@ void CNokia::slotWatchdog()
 
     qDebug() << "void CNokia::slotWatchdog()";
 
-    sysError = tr("Try to start GPS.");
+    //sysError = tr("Try to start GPS.");
     emit sigNewData(*this);
-    location_gpsd_control_stop((LocationGPSDControl *) control);
+    //location_gpsd_control_stop((LocationGPSDControl *) control);
 
     qApp->processEvents();
 
-    sysError = (device != NULL) ? "" : tr("Failed to start GPS. Retry...");
-    location_gpsd_control_start((LocationGPSDControl *) control);
+    //sysError = (device != NULL) ? "" : tr("Failed to start GPS. Retry...");
+    //location_gpsd_control_start((LocationGPSDControl *) control);
     emit sigNewData(*this);
 
     (device != NULL) ? watchdog->start(10000) : watchdog->start(10000);
+    portChanged();
 }
